@@ -107,22 +107,24 @@ let test_pread_bigarray () =
   try
     let size = 65536 in
     let s = String.make size 'x' in
-    assert_equal (Unix.write fd s 0 size) size;
+    assert_equal (Unix.write_substring fd s 0 size) size;
     let t = Bigarray.Array1.create Bigarray.int8_unsigned Bigarray.c_layout size in
     assert_equal (pread fd 0 t) size;
     cmp_buf t 'x' "pread read bad data";
-    ignore (single_pread fd 0 t);
+    assert_equal (single_pread fd 0 t) size;
+    cmp_buf t 'x' "pread read bad data";
     let t = Bigarray.Array1.create Bigarray.int8_unsigned Bigarray.c_layout size in
     assert_equal (LargeFile.pread fd Int64.zero t) size;
     cmp_buf t 'x' "Largefile.pread read bad data";
-    ignore (LargeFile.single_pread fd Int64.zero t);
+    assert_equal (LargeFile.single_pread fd Int64.zero t) size;
+    cmp_buf t 'x' "Largefile.single_pread read bad data";
     Unix.close fd;
     Unix.unlink name
   with exn -> Unix.close fd; Unix.unlink name; raise exn
 
-let cmp_str str c text =
-  for i = 0 to String.length str - 1 do
-    if str.[i] <> c
+let cmp_bytes str c text =
+  for i = 0 to Bytes.length str - 1 do
+    if Bytes.get str i <> c
     then assert_failure text;
   done
 
@@ -137,11 +139,11 @@ let test_pwrite_bigarray () =
     let rec loop off = function
       | 0 -> ()
       | size ->
-	let len = Unix.read fd dst off size
-	in
-	loop (off + len) (size - len)
+        let len = Unix.read fd dst off size
+        in
+        loop (off + len) (size - len)
     in
-    loop 0 (String.length dst)
+    loop 0 (Bytes.length dst)
   in
   try
     let size = 65536 in (* Must be larger than UNIX_BUFFER_SIZE (16384) *)
@@ -150,17 +152,21 @@ let test_pwrite_bigarray () =
       Bigarray.Array1.set s i (int_of_char 'x');
     done;
     assert_equal (pwrite fd 0 s) size;
-    let t = String.make size ' ' in
+    let t = Bytes.make size ' ' in
     read t;
-    cmp_str t 'x' "pwrite wrote bad data";
-    ignore (single_pwrite fd 0 s);
+    cmp_bytes t 'x' "pwrite wrote bad data";
+    assert_equal (single_pwrite fd 0 s) size;
+    read t;
+    cmp_bytes t 'x' "single_pwrite wrote bad data";
     for i = 0 to size - 1 do
       Bigarray.Array1.set s i (int_of_char 'y');
     done;
     assert_equal (LargeFile.pwrite fd Int64.zero s) size;
     read t;
-    cmp_str t 'y' "Largefile.pwrite wrote bad data";
-    ignore (LargeFile.single_pwrite fd Int64.zero s);
+    cmp_bytes t 'y' "Largefile.pwrite wrote bad data";
+    assert_equal (LargeFile.single_pwrite fd Int64.zero s) size;
+    read t;
+    cmp_bytes t 'y' "Largefile.single_pwrite wrote bad data";
     Unix.close fd;
     Unix.unlink name
   with exn -> Unix.close fd; Unix.unlink name; raise exn
@@ -181,13 +187,14 @@ let test_read_bigarray () =
   try
     let size = 65536 in
     let s = String.make size 'x' in
-    assert_equal (Unix.write fd s 0 size) size;
+    assert_equal (Unix.write_substring fd s 0 size) size;
     let t = Bigarray.Array1.create Bigarray.int8_unsigned Bigarray.c_layout size in
     assert_equal (Unix.lseek fd 0 Unix.SEEK_SET) 0;
     assert_equal (read fd t) size;
     cmp_buf t 'x' "read read bad data";
     assert_equal (Unix.lseek fd 0 Unix.SEEK_SET) 0;
-    ignore (single_read fd t);
+    assert_equal (single_read fd t) size;
+    cmp_buf t 'x' "single_read read bad data";
     Unix.close fd;
     Unix.unlink name
   with exn -> Unix.close fd; Unix.unlink name; raise exn
@@ -203,11 +210,11 @@ let test_write_bigarray () =
     let rec loop off = function
       | 0 -> ()
       | size ->
-	let len = Unix.read fd dst off size
-	in
-	loop (off + len) (size - len)
+        let len = Unix.read fd dst off size
+        in
+        loop (off + len) (size - len)
     in
-    loop 0 (String.length dst)
+    loop 0 (Bytes.length dst)
   in
   try
     let size = 65536 in (* Must be larger than UNIX_BUFFER_SIZE (16384) *)
@@ -216,10 +223,12 @@ let test_write_bigarray () =
       Bigarray.Array1.set s i (int_of_char 'x');
     done;
     assert_equal (write fd s) size;
-    let t = String.make size ' ' in
+    let t = Bytes.make size ' ' in
     read t;
-    cmp_str t 'x' "write wrote bad data";
-    ignore (single_write fd s);
+    cmp_bytes t 'x' "write wrote bad data";
+    assert_equal (single_write fd s) size;
+    read t;
+    cmp_bytes t 'x' "write wrote bad data";
     Unix.close fd;
     Unix.unlink name
   with exn -> Unix.close fd; Unix.unlink name; raise exn
